% bruceABME_fig4  Run simulations and plot results corresponding to
%                 Figure 4 from:
%
%                 Bruce, I. C. (2007). "Implementation issues in
%                 approximate methods for stochastic HodgkinHuxley
%                 models," Annals of Biomedical Engineering 35(2):315318.
%
% Ian C. Bruce (ibruce@ieee.org)  2007

% Simulate response of deterministic HH model with floor(N_Na) to
% preconditioned pulse
[V,N_Na,Istim,t] = stochasticHH('hhfloor',[2.5 3.5]/0.265);

figure
hfloor = plot(t,V,'k--','linewidth',1.5);
axis([-0.0200 1.8000 0 150])
hold on

% Simulate response of deterministic HH model with nint(N_Na) to
% preconditioned pulse
[V,N_Na,Istim,t] = stochasticHH('hhnint',[2.5 3.5]/0.265);

hnint = plot(t,V,'k-','linewidth',1.5);

% Plot stimulus scaled by the membrane resistance
Rm = 1953.49e3; % Membrane resistance in kOhms [Rm = 1.95349e3 MOhms]
hstim = plot([-0.02 0 t],[0 0 Istim*Rm],'-','color',0.5*ones(1,3),'linewidth',1.0);

xlabel('Time [ms]')
ylabel('V [mV]')

legend([hstim hfloor hnint],'stimulus','\lfloorN_{Na}\rfloor','nint(N_{Na})')
